--[[

Copyright (C) 2010 Andre Leiradella

This software is provided 'as-is', without any express or implied
warranty. In no event will the authors be held liable for any damages
arising from the use of this software.

Permission is granted to anyone to use this software for any purpose,
including commercial applications, and to alter it and redistribute it
freely, subject to the following restrictions:

1. The origin of this software must not be misrepresented; you must not
claim that you wrote the original software. If you use this software
in a product, an acknowledgment in the product documentation would be
appreciated but is not required.

2. Altered source versions must be plainly marked as such, and must not be
misrepresented as being the original software.

3. This notice may not be removed or altered from any source
distribution.

]]

--[[

Generates a TIGRS (TM) logo to be displayed on the screen.

Edit the contents of tigrs/tigrs.cfg to suit your needs. To generate the
rating box, write:

	require 'tigrs.tigrs'
	tigrs = getRatingBox()

to draw the logo, write:

  tigrs:draw( x, y )

If x is nil, the logo is horizontally centered. If y is new, the logo is
vertically centered.

The TIGRS (TM) name, logo, and ratings are trademarks of Daniel Kinney.

]]

local function trim( str )
	return str:gsub( '%s*([^%s]*)%s*', '%1' )
end

function getRatingBox()
	local tigrs = {}

	-- Read the configuration.
	local file = love.filesystem.newFile( 'tigrs/tigrs.cfg' )
	file:open( 'r' )
	for line in file:lines() do
		line = trim( line:match( '([^#]*)#?.*' ) )

		if line ~= '' then
			local key, value = line:match( '(.*)=(.*)' )
			
			if key and value then
				tigrs[ trim( key ) ] = trim( value )
			end
		end
		print()
	end
	file:close()

	-- Rating.
	if tigrs.rating == 'Family friendly' then
		tigrs.rating = love.graphics.newImage( 'tigrs/tigrs-horizontal-family-crystal.png' )
	elseif tigrs.rating == 'Teen content' then
		tigrs.rating = love.graphics.newImage( 'tigrs/tigrs-horizontal-teen-crystal.png' )
	else -- if tigrs.rating == 'Adult content' then
		tigrs.rating = love.graphics.newImage( 'tigrs/tigrs-horizontal-adult-crystal.png' )
	end

	-- Cartoon violence.
	if tigrs.cartoon_violence ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.cartoon_violence
	end

	-- Fantasy Violence
	if tigrs.fantasy_violence ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.fantasy_violence
	end

	-- Realistic Violence
	if tigrs.realistic_violence ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.realistic_violence
	end

	-- Bloodshed
	if tigrs.bloodshed ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.bloodshed
	end

	-- Sexual Violence
	if tigrs.sexual_violence ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.sexual_violence
	end

	-- Alcohol
	if tigrs.alcohol ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.alcohol
	end

	-- Drugs
	if tigrs.drugs ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.drugs
	end

	-- Tobacco
	if tigrs.tobacco ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.tobacco
	end

	-- Nudity
	if tigrs.nudity ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.nudity
	end

	-- Sexual Themes
	if tigrs.sexual_themes ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.sexual_themes
	end

	-- Sexual Violence
	if tigrs.sexual_violence ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.sexual_violence
	end

	-- Language
	if tigrs.language ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.language
	end

	-- Humor
	if tigrs.humor ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.humor
	end

	-- Gambling
	if tigrs.gambling ~= '' then
		tigrs[ #tigrs + 1 ] = tigrs.gambling
	end

	local text_width = 0, 0
	local font       = love.graphics.newFont( 'tigrs/DejaVuSans-Bold.ttf', 13 )

	for _, text in ipairs( tigrs ) do
		local width = font:getWidth( text )
		
		if width > text_width then
			text_width = width
		end
	end

	tigrs.font         = font
	tigrs.text_width   = text_width
	tigrs.line_height  = line_height
	tigrs.width        = #tigrs ~= 0 and text_width + tigrs.rating:getWidth() + 16 or tigrs.rating:getWidth()
	tigrs.height       = tigrs.rating:getHeight()

	tigrs.draw = function( self, x0, y0 )
		-- Center x.
		if not x0 then
			x0 = ( love.graphics.getWidth() - self.width ) / 2
		end
		-- Center y.
		if not y0 then
			y0 = ( love.graphics.getHeight() - self.height ) / 2
		end
		
		if #tigrs ~= 0 then
			-- Draw the box white background.
			local box_left  = x0 + self.width - self.text_width - 26
			local box_width = self.text_width + 25
			love.graphics.setColor( 255, 255, 255 )
			love.graphics.rectangle( 'fill', box_left, y0, box_width, self.height )
			
			-- Draw the box borders.
			love.graphics.setColor( 0, 0, 0 )
			love.graphics.rectangle( 'fill', box_left, y0, box_width, 6 )
			love.graphics.rectangle( 'fill', box_left, y0 + self.height - 6, box_width, 6 )
			love.graphics.rectangle( 'fill', x0 + self.width - 6, y0, 6, self.height )
		end
		
		-- Draw the rating logo.
		love.graphics.setColor( 255, 255, 255 )
		love.graphics.draw( self.rating, x0, y0 )
		
		-- Draw the text.
		love.graphics.setColor( 0, 0, 0 )
		love.graphics.setFont( self.font )
		
		x0 = x0 + self.rating:getWidth() + 5
		local y = y0 + 5
		local line_height = self.font:getHeight()
		for _, text in ipairs( self ) do
			y = y + line_height
			love.graphics.print( text, x0, y )
		end
	end

	return tigrs
end
